/* adler32.c */
/* Compute the Adler32 checksum (RFC 1950) */

#include <string.h>

#include "adler32.h"

#define BASE 65521 /* largest prime smaller than 65536 */

/*--- update_adler32 --------------------------------------------------------*/
unsigned long update_adler32(unsigned long adler, const unsigned char *buf, int len)
{
  unsigned long s1 = adler & 0xffff;
  unsigned long s2 = (adler >> 16) & 0xffff;
  int n;

  for (n = 0; n < len; n++) {
    s1 = (s1 + buf[n]) % BASE;
    s2 = (s2 + s1)     % BASE;
  }
  return (s2 << 16) + s1;
}

/*--- adler32 ---------------------------------------------------------------*/
unsigned long adler32(unsigned char *buf, int len)
{
  return update_adler32(1L, buf, len);
}

/*--- adler32_str -----------------------------------------------------------*/
unsigned long adler32_str(const char *buf)
{
  return update_adler32(1L, (unsigned char*)buf, strlen(buf));
}

/*---------------------------------------------------------------------------*/
